==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CAPITALPLANREQUESTID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type", propOrder = {
    "investmentplanningid",
    "capitalplanrequestid"
})
public class INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type {

    @XmlElement(name = "INVESTMENTPLANNINGID", required = true)
    protected STANDARDENTITYID_Type investmentplanningid;
    @XmlElement(name = "CAPITALPLANREQUESTID", required = true)
    protected CAPITALPLANREQUESTID_Type capitalplanrequestid;

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

    /**
     * Gets the value of the capitalplanrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public CAPITALPLANREQUESTID_Type getCAPITALPLANREQUESTID() {
        return capitalplanrequestid;
    }

    /**
     * Sets the value of the capitalplanrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public void setCAPITALPLANREQUESTID(CAPITALPLANREQUESTID_Type value) {
        this.capitalplanrequestid = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPITALPLANREQUESTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type", propOrder = {
    "investmentplanningid",
    "capitalplanrequestid"
})
public class INVESTMENTPLANNINGCAPITALPLANNINGREQUESTID_Type {

    @XmlElement(name = "INVESTMENTPLANNINGID", required = true)
    protected STANDARDENTITYID_Type investmentplanningid;
    @XmlElement(name = "CAPITALPLANREQUESTID", required = true)
    protected CAPITALPLANREQUESTID_Type capitalplanrequestid;

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

    /**
     * Gets the value of the capitalplanrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public CAPITALPLANREQUESTID_Type getCAPITALPLANREQUESTID() {
        return capitalplanrequestid;
    }

    /**
     * Sets the value of the capitalplanrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public void setCAPITALPLANREQUESTID(CAPITALPLANREQUESTID_Type value) {
        this.capitalplanrequestid = value;
    }

}
